@@ -14,24 +14,31 @@ Usage::
 from typing import IO, Any, Dict, Type, Union
 
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_sagemaker_runtime.type_defs import InvokeEndpointOutputTypeDef
 
 __all__ = ("SageMakerRuntimeClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    ClientError: Type[Boto3ClientError]
-    InternalFailure: Type[Boto3ClientError]
-    ModelError: Type[Boto3ClientError]
-    ServiceUnavailable: Type[Boto3ClientError]
-    ValidationError: Type[Boto3ClientError]
+    ClientError: Type[BotocoreClientError]
+    InternalFailure: Type[BotocoreClientError]
+    ModelError: Type[BotocoreClientError]
+    ServiceUnavailable: Type[BotocoreClientError]
+    ValidationError: Type[BotocoreClientError]
 
 
 class SageMakerRuntimeClient:
     """
-    [SageMakerRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
+    [SageMakerRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
     """
 
     meta: ClientMeta
@@ -39,7 +46,7 @@ class SageMakerRuntimeClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -50,7 +57,7 @@ class SageMakerRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
         """
 
     def invoke_endpoint(
@@ -64,5 +71,5 @@ class SageMakerRuntimeClient:
         TargetVariant: str = None,
     ) -> InvokeEndpointOutputTypeDef:
         """
-        [Client.invoke_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
+        [Client.invoke_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
         """
